@@ -10,7 +10,7 @@ class BobsledClient:
     
     def __init__(self, credentials, base_url = "http://127.0.0.1:3000"):
         self.credentials = credentials
-        self.base_url = base_url
+        self.base_url = base_url.strip("/")
         self.s = requests.Session()
         headers = {
             "User-Agent": "Bobsled-Python-SDK/Python",
@@ -120,6 +120,8 @@ class BobsledClient:
         
         def archive(self):
             """Archives current share
+            
+            :calls; `POST /shares/{share_id}`
             """            
             
             params = {
@@ -141,6 +143,8 @@ class BobsledClient:
                 
         def restore(self):
             """Restores this archived share
+            
+            :calls: `POST /shares/{share_id}`
             """            
             params = {
                 "_data": "routes/__auth/shares.archived.$archivedShareId"
@@ -168,7 +172,7 @@ class BobsledClient:
             
             :param params: dictionary containing several optional fields
             """            
-            
+        
             r = self.s.post(
                 self.base_url + "/shares/" + self.share_id + 
                 "/driver",
@@ -332,7 +336,7 @@ class BobsledClient:
             share_info = self.get_share_information()
             return share_info["deliveries"]
 
-        def create_delivery(self, selection, size = 1000):
+        def create_delivery(self, selection, size = 1000, overwriteMode = True):
             """Creates and returns a Delivery object given selection of file paths
 
             :calls: `POST /shares/{share_id}/delivery`
@@ -341,19 +345,15 @@ class BobsledClient:
 
             data = {
                 "sharedFiles": selection.__str__().replace("\', \'", "\',\'").replace(
-                    "\'", "\""),# .replace(" ", "+"),  # we have to fit specific format
-                "totalSize": size # placeholder
+                    "\'", "\""), # we have to fit specific format
+                "totalSize": size, # placeholder
+                "overwriteMode": str(overwriteMode).lower()
             }
             
-            # params = {
-            #     "_data": "routes/__auth/shares.$shareId/delivery"
-            # }
-            
             r = self.s.post(
                 self.base_url + "/shares/" + self.share_id +
                 "/delivery",
                 data=data,
-            #    params=params,
                 allow_redirects=False)
             
             if r.status_code != 302:
@@ -456,14 +456,13 @@ class BobsledClient:
             if r.status_code != 200:
                 handle_errors(r)
 
-        def edit_access_identifiers(self, ARN_list):
+        def add_access_identifiers(self, ARN_list):
             """Edit access identifiers of this share
 
             :param ARN_list: list of access identifiers for this share
             """            
             data = {
-                "accessIdentifiers": ARN_list.__str__().replace(" ", "").replace(
-                    "\'", "\"")
+                "accessIdentifiers": ARN_list
             }
             params = {
                 "_data": "routes/__auth/shares.$shareId/destination/edit"
@@ -472,7 +471,30 @@ class BobsledClient:
                 self.base_url + "/shares/" + self.share_id +
                 "/destination/edit",
                 data=data)
-            if r.status_code != 204:
+            if r.status_code != 204 and r.status_code != 200:
+                handle_errors(r)
+                
+        def remove_access_identifiers(self, ARN_list):
+            """Remove access identifiers of this share
+
+            :param ARN_list: list of access identifiers for this share
+            """            
+            
+            # we want to change ARNs into their ids
+            ARN_id_list = []
+            
+            
+            data = {
+                "accessIdentifiers": ARN_list
+            }
+            params = {
+                "_data": "routes/__auth/shares.$shareId/destination/edit"
+            }
+            r = self.s.post(
+                self.base_url + "/shares/" + self.share_id +
+                "/destination/edit",
+                data=data)
+            if r.status_code != 204 and r.status_code != 200:
                 handle_errors(r)
 
         class Delivery:
@@ -492,7 +514,6 @@ class BobsledClient:
             def __repr__(self):
                 return "Delivery(" + self.delivery_id + ")"
 
-            # maybe rename this? 
             def deliver_delivery(self):
                 """Delivers this Delivery
                 
@@ -526,7 +547,7 @@ class BobsledClient:
             def access(self):
                 """Returns the URL to access this delivery
 
-                :calls: `GET
+                :calls: `GET /shares/{share_id}/deliveries/{delivery_id}/access`
                 :return: URL where deliveries can be accessed
                 """                
                 
@@ -542,8 +563,4 @@ class BobsledClient:
                     handle_errors(r)
                 
                 url = r.json()["delivery"]["url"]
-                return url
-
-            def edit_delivery(self):
-                # Unimplemented
-                return
\ No newline at end of file
+                return url
\ No newline at end of file
